@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-from .client import load_json, ingest_data, write_parquet, convert_json
+from .client import load_json, ingest_data, write_parquet, convert_json, write_parquet_dataset
 
 __title__ = 'json2parquet'
-__version__ = '0.0.22'
+__version__ = '1.0.0'
 
 __all__ = ['load_json', 'ingest_data', 'write_parquet', 'convert_json', 'write_parquet_dataset']
